@@ -1,3 +1,4 @@
+from dt.ext.aws_s3 import get_lastest_file
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
 import ipdb
@@ -410,6 +411,25 @@ class Base(Controller):
         n_lines = [int(x) for x in str(self.app.pargs.n).split(',')]
         run_command(n_lines)
 
+
+    @ex(
+        help='Operations with s3 bucket creationlabs-raw-data',
+        arguments=[
+            (['action'],{
+                "help" : "One of {ls, rm, cp, mv, download, upload}",
+                "action" : "store"
+            }),
+            (['target'],{
+                "help" : "The target of the action. Can be a file or a directory",
+                "action" : "store"
+            })
+        ]
+    )
+    def s3(self):
+        from ..ext.aws_s3 import get_lastest_file
+        if self.app.pargs.action == '-1':
+            get_lastest_file(self.app.pargs.target)
+
     @ex(
         help='Operations on the SSH config',
         arguments=[
@@ -515,35 +535,6 @@ class Base(Controller):
             raise NotImplementedError("Try one of {show, set, loc}")
 
 
-    @ex(
-        help='Tracks your ML code till finish',
-        arguments=[
-            (['flags'], {
-                'help' : 'Which  script + flags you want to pass to the underlying python.'
-                         'e.g. train.py --parallel --batch_size 256',
-                'action' : "store"
-            }),
-            (['-ns'], {
-                'help' : 'Shuts down the computer between in the shutdown_hours.'
-                        'Set to 22-08. Default: True',
-                "action" : 'store'
-            }),
-            (['-t'], {
-                'help' : 'If we are testing / doing a dry run. Default: False',
-                "action" : "store"
-            }),
-            (['-cfg'],{
-                'help': "location of the config file",
-                "action" : "store",
-            }),
-            (['-p'],{
-                "help": "which Python interpreter to use."
-                        " Default is determined by `which python3`",
-                "action" : "store"
-            })
-        ]
-    )
-
     @ex(
         help='All Github related operations',
         arguments=[
